# UpdateModelBatchJobDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**model_batch_id** | **str** |  | [optional] 
**project_id** | **str** |  | [optional] 
**type** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**config** | **object** |  | [optional] 
**analysis_job_id** | **str** |  | [optional] 
**cohort_id** | **str** |  | [optional] 
**partial_model_population_id** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

